"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const path_1 = require("path");
exports.access = util_1.promisify(fs_1.default.access);
exports.appendFile = util_1.promisify(fs_1.default.appendFile);
exports.chmod = util_1.promisify(fs_1.default.chmod);
exports.chown = util_1.promisify(fs_1.default.chown);
exports.close = util_1.promisify(fs_1.default.close);
exports.copyFile = util_1.promisify(fs_1.default.copyFile);
exports.exists = util_1.promisify(fs_1.default.exists);
exports.fchmod = util_1.promisify(fs_1.default.fchmod);
exports.fchown = util_1.promisify(fs_1.default.fchown);
exports.fdatasync = util_1.promisify(fs_1.default.fdatasync);
exports.fstat = util_1.promisify(fs_1.default.fstat);
exports.fsync = util_1.promisify(fs_1.default.fsync);
exports.ftruncate = util_1.promisify(fs_1.default.ftruncate);
exports.futimes = util_1.promisify(fs_1.default.futimes);
exports.link = util_1.promisify(fs_1.default.link);
exports.lstat = util_1.promisify(fs_1.default.lstat);
exports.mkdir = util_1.promisify(fs_1.default.mkdir);
exports.mkdtemp = util_1.promisify(fs_1.default.mkdtemp);
exports.open = util_1.promisify(fs_1.default.open);
exports.read = util_1.promisify(fs_1.default.read);
exports.readdir = util_1.promisify(fs_1.default.readdir);
exports.readFile = util_1.promisify(fs_1.default.readFile);
exports.readlink = util_1.promisify(fs_1.default.readlink);
exports.realpath = util_1.promisify(fs_1.default.realpath);
exports.rename = util_1.promisify(fs_1.default.rename);
exports.rmdir = util_1.promisify(fs_1.default.rmdir);
exports.stat = util_1.promisify(fs_1.default.stat);
exports.symlink = util_1.promisify(fs_1.default.symlink);
exports.truncate = util_1.promisify(fs_1.default.truncate);
exports.unlink = util_1.promisify(fs_1.default.unlink);
exports.utimes = util_1.promisify(fs_1.default.utimes);
exports.write = util_1.promisify(fs_1.default.write);
exports.writeFile = util_1.promisify(fs_1.default.writeFile);
/**
 * Check if a path points to an existing file.
 *
 * @param path possible file path
 * @param statFn optional custom stat function (e.g. lstat to detect links)
 */
async function fileExists(path, statFn = exports.stat) {
    try {
        return (await statFn(path)).isFile();
    }
    catch (_a) {
        return false;
    }
}
exports.fileExists = fileExists;
/**
 * Check if a path points to an existing directory.
 *
 * @param path possible directory path
 * @param statFn optional custom stat function (e.g. lstat to detect links)
 */
async function directoryExists(path, statFn = exports.stat) {
    try {
        return (await statFn(path)).isDirectory();
    }
    catch (_a) {
        return false;
    }
}
exports.directoryExists = directoryExists;
/**
 * Ensure a directory and its parent directory chain exists.
 *
 * @param directoryPath directory to ensure
 */
async function ensureDirectory(directoryPath) {
    if (await directoryExists(directoryPath)) {
        return;
    }
    try {
        await exports.mkdir(directoryPath);
    }
    catch (e) {
        const parentPath = path_1.dirname(directoryPath);
        if (parentPath === directoryPath) {
            throw e;
        }
        await ensureDirectory(parentPath);
        await exports.mkdir(directoryPath);
    }
}
exports.ensureDirectory = ensureDirectory;
//# sourceMappingURL=promised-fs.js.map